@@ -13,13 +13,13 @@ from qtgql.codegen.py.objecttype import (
     FieldProperty,
     GqlEnumDefinition,
     GqlTypeDefinition,
+    GqlTypeHinter,
     Kinds,
 )
 from qtgql.codegen.py.scalars import BuiltinScalars
 from qtgql.codegen.utils import anti_forward_ref
-from qtgql.typingref import TypeHinter
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from qtgql.codegen.py.config import QtGqlConfig
 
 introspection_query = graphql.get_introspection_query(descriptions=True)
@@ -30,10 +30,7 @@ class SchemaEvaluator:
         self.template = config.template_class
         self.introspection = introspection
         self.config = config
-        self._generated_types: dict[str, GqlTypeDefinition] = {
-            scalar: GqlTypeDefinition(name=scalar, kind=Kinds.SCALAR, fields=[])
-            for scalar in BuiltinScalars.keys()
-        }
+        self._generated_types: dict[str, GqlTypeDefinition] = {}
         self._generated_enums: EnumMap = {}
         self._evaluate()
 
@@ -47,50 +44,47 @@ class SchemaEvaluator:
         for union in self.unions:
             if union["name"] == name:
                 return union["possibleTypes"]
-        raise ValueError(f"Union for {name} was not found")
+        raise ValueError(f"Union for {name} was not found")  # pragma: no cover
 
-    def evaluate_field_type(self, t: dict) -> TypeHinter:
+    def evaluate_field_type(self, t: dict) -> GqlTypeHinter:
         kind = Kinds(t["kind"])
 
-        is_optional = True
         if kind == Kinds.NON_NULL:
-            # move to inner, this is not optional
+            # There are no optionals in qtgql, we use default values.
+            # By default, everything in graphql is optional,
+            # so NON_NULL doesn't really make a difference,
             t = t["ofType"]
-            is_optional = False
 
         of_type = t["ofType"]
         name = t["name"]
         kind = Kinds(t["kind"])
-        ret: Optional[TypeHinter] = None
-
-        def optional_maybe(inner: TypeHinter) -> TypeHinter:
-            return TypeHinter(type=Optional, of_type=(inner,)) if is_optional else inner
+        ret: Optional[GqlTypeHinter] = None
 
         if kind == Kinds.LIST:
-            ret = TypeHinter(type=list, of_type=(self.evaluate_field_type(of_type),))
+            ret = GqlTypeHinter(type=list, of_type=(self.evaluate_field_type(of_type),))
         elif kind == Kinds.SCALAR:
-            try:
-                ret = TypeHinter(type=BuiltinScalars[name])
-            except KeyError:
-                ret = TypeHinter(type=self.config.custom_scalars[name])
+            if builtin_scalar := BuiltinScalars.by_graphql_name(name):
+                ret = GqlTypeHinter(type=builtin_scalar)
+            else:
+                ret = GqlTypeHinter(type=self.config.custom_scalars[name])
         elif kind is Kinds.ENUM:
-            ret = TypeHinter(type=anti_forward_ref(name=name, type_map=self._generated_enums))
+            ret = GqlTypeHinter(type=anti_forward_ref(name=name, type_map=self._generated_enums))
         elif kind is Kinds.OBJECT:
-            ret = TypeHinter(type=anti_forward_ref(name=name, type_map=self._generated_types))
+            ret = GqlTypeHinter(type=anti_forward_ref(name=name, type_map=self._generated_types))
         elif kind == Kinds.UNION:
-            ret = TypeHinter(
+            ret = GqlTypeHinter(
                 type=Union,
                 of_type=tuple(
-                    TypeHinter(
+                    GqlTypeHinter(
                         type=anti_forward_ref(name=possible["name"], type_map=self._generated_types)
                     )
                     for possible in self.get_possible_types_for_union(name)
                 ),
             )
         if ret:
-            return optional_maybe(ret)
+            return ret
 
-        raise NotImplementedError(f"kind {kind} not supported yet")
+        raise NotImplementedError(f"kind {kind} not supported yet")  # pragma: no cover
 
     def evaluate_field(self, field: dict) -> FieldProperty:
         """we don't really know what is the field type just it's name."""
